@@ -7,7 +7,6 @@ our @EXPORT = qw(FindMethods);
 
 use MOP4Import::Util qw(symtab);
 
-# XXX: rewrite this with mro::get_linear_isa;
 sub FindMethods {
   # depth first, pre-order search of 'sub'.
   # In the real sense, this should be called 'Findsubs'.
@@ -27,14 +26,8 @@ sub FindMethods {
 	$_ =~ $pattern or next;
       }
     }
-    my $globOrCode = $symtab->{$orig};
-    if (ref $globOrCode eq 'CODE') {
-      ; #ok
-    } elsif (ref \$globOrCode eq 'GLOB' and *{$globOrCode}{CODE}) {
-      ; #ok
-    } else {
-      next;
-    }
+    my $glob = $symtab->{$orig};
+    next unless *{$glob}{CODE};
     $found->{$_} //= $class;
   }
 
